<?php

namespace Drupal\static_node\Form;

use Drupal\Core\Form\ConfirmFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\static_node\StaticNodeHooks;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a confirmation form for deleting a static homepage.
 */
class StaticHomepageDeleteForm extends ConfirmFormBase {

  /**
   * The static node hooks service.
   *
   * @var \Drupal\static_node\StaticNodeHooks
   */
  protected $staticNodeHooks;

  /**
   * Constructs a StaticHomepageDeleteForm object.
   *
   * @param \Drupal\static_node\StaticNodeHooks $static_node_hooks
   *   The static node hooks service.
   */
  public function __construct(StaticNodeHooks $static_node_hooks) {
    $this->staticNodeHooks = $static_node_hooks;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('static_node.hooks')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'static_node_homepage_delete_form';
  }

  /**
   * {@inheritdoc}
   */
  public function getQuestion() {
    return $this->t('Are you sure you want to delete the static version of the homepage?');
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelUrl() {
    return Url::fromRoute('static_node.files_management');
  }

  /**
   * {@inheritdoc}
   */
  public function getDescription() {
    return $this->t('This will delete the static HTML file for the homepage. The dynamic page will be served to all users again.');
  }

  /**
   * {@inheritdoc}
   */
  public function getConfirmText() {
    return $this->t('Delete Static Homepage');
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelText() {
    return $this->t('Cancel');
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Delete static homepage
    $this->staticNodeHooks->deleteStaticHomepage();
    
    // Redirect to the files management page
    $form_state->setRedirectUrl(Url::fromRoute('static_node.files_management'));
  }

}
